@@ -3,7 +3,7 @@
  * The base configuration for WordPress
  *
  * The wp-config.php creation script uses this file during the installation.
- * You don't have to use the website, you can copy this file to "wp-config.php"
+ * You don't have to use the web site, you can copy this file to "wp-config.php"
  * and fill in the values.
  *
  * This file contains the following configurations:
@@ -11,28 +11,29 @@
  * * Database settings
  * * Secret keys
  * * Database table prefix
+ * * Localized language
  * * ABSPATH
  *
- * @link https://developer.wordpress.org/advanced-administration/wordpress/wp-config/
+ * @link https://wordpress.org/support/article/editing-wp-config-php/
  *
  * @package WordPress
  */
 
 // ** Database settings - You can get this info from your web host ** //
 /** The name of the database for WordPress */
-define( 'DB_NAME', 'autf7216_autoone_serpong' );
+define( 'DB_NAME', 'techfrea_wp_xdb8z' );
 
 /** Database username */
-define( 'DB_USER', 'autf7216_autoone_serpong' );
+define( 'DB_USER', 'techfrea_wp_l1ggo' );
 
 /** Database password */
-define( 'DB_PASSWORD', 'Spe.1-S50p' );
+define( 'DB_PASSWORD', 'DVZa!*l5L8fI~^9v' );
 
 /** Database hostname */
-define( 'DB_HOST', 'localhost' );
+define( 'DB_HOST', 'localhost:3306' );
 
 /** Database charset to use in creating database tables. */
-define( 'DB_CHARSET', 'utf8mb4' );
+define( 'DB_CHARSET', 'utf8' );
 
 /** The database collate type. Don't change this if in doubt. */
 define( 'DB_COLLATE', '' );
@@ -48,14 +49,15 @@ define( 'DB_COLLATE', '' );
  *
  * @since 2.6.0
  */
-define( 'AUTH_KEY',         'ftthzoiwhyalosnnaxyydhufxb989cnttpwstornyxf9w3i4cotmzwkh8iifg4th' );
-define( 'SECURE_AUTH_KEY',  'pthsfk2mfntfdsezww98ky9kidotg4qjjbreygbngzain0imaaeusndxurs4n3b3' );
-define( 'LOGGED_IN_KEY',    'zqyndvsuvdyk44ifwbvjj3kzmmxiqrwvfcissvfcvmp5n7ebvmlxfk23n5iyh5ph' );
-define( 'NONCE_KEY',        'gd4pj0fbnz8ecucozdqgajqbxnq1ibrovwv3mig2bcxmptsr7cxmmwltzl7hxowx' );
-define( 'AUTH_SALT',        'og1swzauc0y5jzjuwh8h7ruxwzurchdmzmkvar5diibi4jcpdys2nikxibrxrqyh' );
-define( 'SECURE_AUTH_SALT', 'qgdazojgwegyfck9r5iw26rcdbcugakcfu1xq1pkoctkmji6trysigrr8hxdesie' );
-define( 'LOGGED_IN_SALT',   'rt4wqiuta0mwqdqg2psuhufyrgnjlzev06n67zqd3jhzmo5goenyal16jyhhqlwv' );
-define( 'NONCE_SALT',       'rotl16cbjre0asuelohijwualywyvfipurjsecpxg0sqewqm6br9kvwzllc2gbnl' );
+define('AUTH_KEY', 's&&d5G+M(7-I7Ff;[xn#57/JeJ%K1T&vm&(-eNr4]QtxeTI:f&#!0m_1sDs2o&vB');
+define('SECURE_AUTH_KEY', 'n+6nN4h&03E3MO7aj)vzs1nh+b|6@9Tj4Nd6[34+O8&/8g&BB44&7#-4Iu![83#1');
+define('LOGGED_IN_KEY', '3!fp*+E/kt%9B@KsN3:nEE/y]j@rJ-q8oe8;1jy&MENCs7v!fnIav]tF-90XXN-g');
+define('NONCE_KEY', 'v-g4S|V45~44/|[6PK26zqIu[7]~2C137|bd|rMIdJF8ekaK8fmIiCLju_[)k!%d');
+define('AUTH_SALT', '3s&-@A-9;6G8Qf!x5Ky/]R1-9EB1_4&2qy+MgPTWN!z58w9(ReRp7*7j/g[ch4(L');
+define('SECURE_AUTH_SALT', 'Hr~-r)1GB|3Mo!:*ftd8![v(|qL+#4!61zSm36-@!Na7(tP85J4t65H35:QxB8&9');
+define('LOGGED_IN_SALT', ']9J+k5_#&NS16t8tq6+v5:2Ob1CF][uk885:8+7tl1[~mi)MDfDq4d+/5&H8Aqu9');
+define('NONCE_SALT', 'O/;0-wI]H86DGMBR24+U[X@_un*;cv120;*CVr5R5K054h7nkxh!7;2BO*4sF9+2');
+
 
 /**#@-*/
 
@@ -64,15 +66,13 @@ define( 'NONCE_SALT',       'rotl16cbjre0asuelohijwualywyvfipurjsecpxg0sqewqm6br
  *
  * You can have multiple installations in one database if you give each
  * a unique prefix. Only numbers, letters, and underscores please!
- *
- * At the installation time, database tables are created with the specified prefix.
- * Changing this value after WordPress is installed will make your site think
- * it has not been installed.
- *
- * @link https://developer.wordpress.org/advanced-administration/wordpress/wp-config/#table-prefix
  */
-$table_prefix = 'autoone';
+$table_prefix = 'D8WJyrYW_';
 
+
+/* Add any custom values between this line and the "stop editing" line. */
+
+define('WP_ALLOW_MULTISITE', true);
 /**
  * For developers: WordPress debugging mode.
  *
@@ -83,13 +83,11 @@ $table_prefix = 'autoone';
  * For information on other constants that can be used for debugging,
  * visit the documentation.
  *
- * @link https://developer.wordpress.org/advanced-administration/debug/debug-wordpress/
+ * @link https://wordpress.org/support/article/debugging-in-wordpress/
  */
-define( 'WP_DEBUG', false );
-
-/* Add any custom values between this line and the "stop editing" line. */
-
-
+if ( ! defined( 'WP_DEBUG' ) ) {
+	define( 'WP_DEBUG', false );
+}
 
 /* That's all, stop editing! Happy publishing. */
 
